@@ -28,7 +28,7 @@ __all__ = (
     'kivy_config_fn', 'kivy_usermodules_dir',
 )
 
-__version__ = '1.7.0'
+__version__ = '1.7.1'
 
 import sys
 import shutil
@@ -186,7 +186,7 @@ else:
 
 #: Global settings options for kivy
 kivy_options = {
-    'window': ('pygame', 'sdl', 'x11'),
+    'window': ('egl_rpi', 'pygame', 'sdl', 'x11'),
     'text': ('pil', 'pygame', 'sdlttf'),
     'video': ('ffmpeg', 'gstreamer', 'pyglet'),
     'audio': ('pygame', 'gstreamer', 'sdl'),
